@@ -2,7 +2,8 @@ from django.core.validators import MinValueValidator
 from django.db import models
 from edc_constants.choices import YES_NO
 from edc_constants.constants import NOT_APPLICABLE
-from edc_model.models import OtherCharField, date_not_future
+from edc_model.models import OtherCharField
+from edc_model.validators import date_not_future
 from edc_protocol.validators import date_not_before_study_start
 
 from ..choices import BACTERIA_TYPE, BLOOD_CULTURE_RESULTS_ORGANISM, CULTURE_RESULTS
